recordStore.BdbRecordIter

|  | ## Cheshire3 Object Model: Class BdbRecordIter

Module recordStore :: Class BdbRecordIter

## Class BdbRecordIter
source code

Object Tree:

           object --+
                    |
    baseStore.BdbIter --+
                        |
                       BdbRecordIter

Instance Methods

next(self)
Inherited from `baseStore.BdbIter`: `__init__`, `__iter__`, `jump` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `baseStore.BdbIter`: `cursor`, `cxn`, `nextData`, `store` Inherited from `object`: `__class__`

Method Details

### next(self) | source code
Overrides: baseStore.BdbIter.next